@@ -1,5 +1,5 @@
 from django.conf import settings
-from django.contrib import admin
+from django.contrib import admin, messages
 from django.http import HttpResponse
 from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth import get_user_model
@@ -94,6 +94,14 @@ class QRCodeAdmin(admin.ModelAdmin):
         return custom_urls + urls
 
     def scan_view(self, request):
+        if request.method == 'POST':
+            uuid = request.POST['short_uuid']
+            try:
+                code = QRCode.objects.get(uuid)
+                return redirect('admin:qrtoolkit_core_qrcode_change', kwargs={'object_id': code.pk})
+            except QRCode.DoesNotExist:
+                self.message_user(request, f'Qr code with uuid {uuid} not found.', level=messages.WARNING)
+
         context = dict(
             # Include common variables for rendering the admin template.
             self.admin_site.each_context(request),
@@ -101,7 +109,6 @@ class QRCodeAdmin(admin.ModelAdmin):
             is_nav_sidebar_enabled=False,
             title='Scan qr code'
         )
-
         return TemplateResponse(request, 'qrtoolkit_core/qrcode/scanner.html', context)
 
     def download_codes(self, request):
