@@ -29,7 +29,7 @@ class ApiHit(models.Model):
 
 class Department(models.Model):
     name = models.CharField(max_length=128, unique=True)
-    users = models.ManyToManyField('auth.User', related_name='departments')
+    users = models.ManyToManyField('auth.User', related_name='departments', blank=True)
 
     def __str__(self) -> str:
         return f'{self.name}'
